summaryrefslogtreecommitdiffstats
path: root/korganizer/koagendaitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koagendaitem.cpp')
-rw-r--r--korganizer/koagendaitem.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/korganizer/koagendaitem.cpp b/korganizer/koagendaitem.cpp
index de1f4ef8..21eea0e1 100644
--- a/korganizer/koagendaitem.cpp
+++ b/korganizer/koagendaitem.cpp
@@ -737,16 +737,16 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
if ( !mIncidence )return;
TQRect visRect = visibleRect();
- // when scrolling horizontally in the side-by-side view, the repainted area is clipped
+ // when scrolling horizontally in the side-by-side view, the tqrepainted area is clipped
// to the newly visible area, which is a problem since the content changes when visRect
// changes, so repaint the full item in that case
if ( ev->rect() != visRect && visRect.isValid() && ev->rect().isValid() ) {
- repaint( visRect );
+ tqrepaint( visRect );
return;
}
TQPainter p( this );
- const int ft = 2; // frame thickness for layout, see paintFrame()
+ const int ft = 2; // frame thickness for tqlayout, see paintFrame()
const int margin = 1 + ft; // frame + space between frame and content
// General idea is to always show the icons (even in the all-day events).
@@ -769,7 +769,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
if ( static_cast<Todo*>(mIncidence)->isOverdue() )
bgColor = KOPrefs::instance()->todoOverdueColor();
else if ( static_cast<Todo*>(mIncidence)->dtDue().date() ==
- TQDateTime::currentDateTime().date() )
+ TQDateTime::tqcurrentDateTime().date() )
bgColor = KOPrefs::instance()->todoDueTodayColor();
}
@@ -737,16 +737,16 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
// to the newly visible area, which is a problem since the content changes when visRect
- // changes, so repaint the full item in that case
+ // changes, so tqrepaint the full item in that case
if ( ev->rect() != visRect && visRect.isValid() && ev->rect().isValid() ) {